WorldMap = require "worldmap"

function love.load()
	pixel = 4
	map = createWorld(pixel)
	draw = drawHeightMap
end

function love.keypressed(key)
	if key == "r" then
		map = createWorld(pixel)
	elseif key == "h" then
		draw = drawHeightMap
	elseif key == "c" then
		draw = drawContours
	elseif key == "t" then
		draw = drawTemperatures
	elseif key == "g" then
		draw = drawGroundTemp
	elseif key == "[" then
		WorldMap.MaxIrradiation = WorldMap.MaxIrradiation - 1
		print("irradiation", WorldMap.MaxIrradiation)
	elseif key == "]" then
		WorldMap.MaxIrradiation = WorldMap.MaxIrradiation + 1
		print("irradiation", WorldMap.MaxIrradiation)
	elseif key == "-" then
		WorldMap.HeatCapacityCoefficient = WorldMap.HeatCapacityCoefficient - 1
		print("HeatCapacityCoefficient", WorldMap.HeatCapacityCoefficient)
	elseif key == "=" then
		WorldMap.HeatCapacityCoefficient = WorldMap.HeatCapacityCoefficient + 1
		print("HeatCapacityCoefficient", WorldMap.HeatCapacityCoefficient)
	
	elseif key == "up" then
		map:runHeatMap(365/12)
		print("day: ", map:getDay())
	elseif key == "right" then
		map:runHeatMap(1)
		print("day: ", map:getDay())
		for y=1, map:getY() do
			print(y, map:getLatitude(y), map:getAirTemperature(10, y))
		end
	end
end

function love.draw()
	draw()
end


function createWorld(pixel)
	local map = WorldMap(800/pixel, 600/pixel, 100, 65, true)
	map:runHeatMap(365*3)
	lMin = map:getMinHeight()
	lMax = map:getMaxHeight()
	if lMin < 0 then lMin = 0 end
	gStep = (lMax-lMin)/255
	return map
end

function drawHeightMap()
	for x = 1, map:getX() do
		for y = 1, map:getY() do
			local lColor
			if map:getHeight(x, y) < 0 then
				local step = (map:getMinHeight())/128
				local color = 255 - math.floor((map:getHeight(x, y) - map:getMinHeight()) / step)
				love.graphics.setColor(color, color, 255)
			else
				lColor = 255 - math.floor((map:getHeight(x, y) - lMin) / gStep)		
				love.graphics.setColor(lColor, lColor, lColor)
			end
			love.graphics.rectangle("fill", pixel*(x-1), pixel*(y-1), pixel, pixel)
		end
	end
end

function drawContours()
	for x = 1, map:getX() do
		for y = 1, map:getY() do
			local lColor
			if map:getHeight(x, y) < 0 then
				love.graphics.setColor(200, 200, 255)
			else
				love.graphics.setColor(255, 255, 255)
			end
			love.graphics.rectangle("fill", pixel*(x-1), pixel*(y-1), pixel, pixel)
		end
	end
end

local OPACITY = 120
local TEMPERATURECOLORS ={
	{0, 0, 102}; {0, 0, 153}; {0, 0, 204}; {0, 0, 255}; {51, 51, 255}; {102, 102, 255};
	{0, 255, 255}; {0, 255, 128}; {0, 255, 0}; {128, 255, 0}; {255, 255, 0}; {255, 128, 0};
	{255, 0, 0}; {204, 0, 0};
}

function drawGroundTemp()
	drawTemperatures("Ground")
end

function drawTemperatures(pType)
	drawHeightMap()
	local lTemp
	if pType == "Ground" then
		lTemp = map._GroundTemperature
	else
		lTemp = map._AirTemperature
	end
	for x = 1, map:getX() do
		for y = 1, map:getY() do
			local tmp = math.floor(lTemp[x][y] / 5) + 7
			if tmp < 1 then tmp = 1 end
			if tmp > #TEMPERATURECOLORS then tmp = #TEMPERATURECOLORS end
			local color = {TEMPERATURECOLORS[tmp][1], TEMPERATURECOLORS[tmp][2], TEMPERATURECOLORS[tmp][3], OPACITY}
			love.graphics.setColor(unpack(color))
			love.graphics.rectangle("fill", pixel*(x-1), pixel*(y-1), pixel, pixel)
		end
	end
end

